==> cloud-5.0.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/pages/EntitySubViewPage.tsx <==
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import DataColumn from 'model/DataColumn';
import DataRecord from 'model/DataRecord';
import EntityColumn from 'model/EntityColumn';
import EntityInfoTabTemplate from 'model/EntityInfoTabTemplate';
import SortInfo from 'model/SortInfo';
import LoadingSpinner from 'molecules/LoadingSpinner';
import Breadcrumbs from 'organisms/Breadcrumbs';
import DataTable from 'organisms/DataTable';
import PageTitle from 'organisms/PageTitle';
import SideBar from 'organisms/SideBar';
import { useContext, useEffect, useState } from 'react';
import { Col, Container, Form, Row } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import { convertEntityDataToDataRecord } from 'service/convert';
import { AppContext } from 'service/state';

const InfoTabs = ({ cloudContext, tabTemplate, entityId, subType }: {
  cloudContext: string,
  tabTemplate: EntityInfoTabTemplate,
  entityId: string,
  subType: string
}) => {

  const url = `/${tabTemplate.cloudServiceProvider}/${cloudContext}/${tabTemplate.entityName}/${entityId}`;

  return <nav className="tabs">
    <div>
      <ul className="nav nav-tabs">
        <li>
          <Link to={url}
            className="active is-active ripple-effect">
            View
          </Link>
        </li>
        {
          tabTemplate.tabs.map((tabColumn) => {
            return <li className={subType === tabColumn.name ? 'active' : ''} key={tabColumn.name}>
              <Link to={`${url}/${tabColumn.name}`}
                className="active is-active ripple-effect">
                {tabColumn.labelName}
              </Link>
            </li>;
          })
        }
      </ul>
    </div>
  </nav>;

}

const EntitySubViewPage = ({
  cloudContext,
  tabTemplate,
  entityId,
  subType,
}: {
  cloudContext: string,
  tabTemplate: EntityInfoTabTemplate,
  entityId: string,
  subType: string,
}) => {

  const { cloudContextList } = useContext(AppContext);
  const { getEntityListAll } = useDrupalJsonApi();
  const [dataColumnList, setDataColumnList] = useState<DataColumn[]>([]);
  const [dataRecordList, setDataRecordList] = useState<DataRecord[]>([]);
  const [sortInfo, setSortInfo] = useState<SortInfo>({
    key: '', direction: 'ASC'
  });
  const [loadingFlg, setLoadingFlg] = useState(true);

  const getSubTemplate = () => {
    const subTemplates = tabTemplate.tabs.filter((template) => {
      return template.name === subType;
    });

    return subTemplates.length >= 1 ? subTemplates[0] : undefined;
  }

  const getPath = () => {
    return `/${tabTemplate.cloudServiceProvider}/${tabTemplate.entityName}/${entityId}/${subType}`;
  }

  useEffect(() => {
    const init = async () => {
      // Load column data.
      const subTemplate = getSubTemplate();
      if (subTemplate) {
        let newDataColumnList: DataColumn[] = subTemplate.columns.map((column) => {
          return { key: column.name, label: column.labelName };
        });
        setDataColumnList(newDataColumnList);
  
        // Load entity data.
        const entityTypeId = `${tabTemplate.cloudServiceProvider}_${tabTemplate.entityName}_${subType}`;
        const filter: {
            [key: string]: string;
        } = {};
        const filterKey = `filter[${tabTemplate.entityName}_entity_id]`;
        filter[filterKey] = entityId;
        filter['filter[cloud_context]'] = cloudContext;
        const rawData = await getEntityListAll(entityTypeId, filter);
        setDataRecordList(convertEntityDataToDataRecord(entityTypeId, rawData, subTemplate.columns as EntityColumn[], cloudContextList, {}));
        setLoadingFlg(false);
      }
    }

    init();
  }, [cloudContext, tabTemplate, entityId, subType]);

  return <>
    <PageTitle />
    <Breadcrumbs />
    <SideBar />
    <InfoTabs cloudContext={cloudContext} tabTemplate={tabTemplate} entityId={entityId} subType={subType} />
    <Container fluid className="px-0">
      <Row>
        <Col>
          <Form>
            {
              loadingFlg
                ? <LoadingSpinner />
                : <DataTable
                dataColumnList={dataColumnList}
                dataRecordList={dataRecordList}
                sortInfo={sortInfo}
                setSortInfo={setSortInfo}
                hasOperationLinks={false}
                operationLinksName="Operations links"
                detailInfo={
                  typeof getSubTemplate() !== 'undefined'
                    ? {
                      column: 'name',
                      path: getPath()
                    }
                    : undefined
                } />
            }
          </Form>
        </Col>
      </Row>
    </Container>
  </>;

}

export default EntitySubViewPage;

==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/pages/EntitySubViewPage.tsx <==
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import DataColumn from 'model/DataColumn';
import DataRecord from 'model/DataRecord';
import EntityColumn from 'model/EntityColumn';
import EntityInfoTabTemplate from 'model/EntityInfoTabTemplate';
import SortInfo from 'model/SortInfo';
import LoadingSpinner from 'molecules/LoadingSpinner';
import Breadcrumbs from 'organisms/Breadcrumbs';
import DataTable from 'organisms/DataTable';
import PageTitle from 'organisms/PageTitle';
import SideBar from 'organisms/SideBar';
import { useContext, useEffect, useState } from 'react';
import { Col, Container, Form, Row } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import { convertEntityDataToDataRecord } from 'service/convert';
import { AppContext } from 'service/state';

const InfoTabs = ({ cloudContext, tabTemplate, entityId, subType }: {
  cloudContext: string,
  tabTemplate: EntityInfoTabTemplate,
  entityId: string,
  subType: string
}) => {

  const url = `/${tabTemplate.cloudServiceProvider}/${cloudContext}/${tabTemplate.entityName}/${entityId}`;

  return <nav className="tabs">
    <div>
      <ul className="nav nav-tabs" id="tab_wrap">
        <li>
          <Link to={url}
            className="active is-active ripple-effect">
            View
          </Link>
        </li>
        {
          tabTemplate.tabs.map((tabColumn) => {
            return <li className={subType === tabColumn.name ? 'active' : ''} key={tabColumn.name}>
              <Link to={`${url}/${tabColumn.name}`}
                className="active is-active ripple-effect">
                {tabColumn.labelName}
              </Link>
            </li>;
          })
        }
      </ul>
    </div>
  </nav>;

}

const EntitySubViewPage = ({
  cloudContext,
  tabTemplate,
  entityId,
  subType,
}: {
  cloudContext: string,
  tabTemplate: EntityInfoTabTemplate,
  entityId: string,
  subType: string,
}) => {

  const { cloudContextList } = useContext(AppContext);
  const { getEntityListAll } = useDrupalJsonApi();
  const [dataColumnList, setDataColumnList] = useState<DataColumn[]>([]);
  const [dataRecordList, setDataRecordList] = useState<DataRecord[]>([]);
  const [sortInfo, setSortInfo] = useState<SortInfo>({
    key: '', direction: 'ASC'
  });
  const [loadingFlg, setLoadingFlg] = useState(true);

  const getSubTemplate = () => {
    const subTemplates = tabTemplate.tabs.filter((template) => {
      return template.name === subType;
    });

    return subTemplates.length >= 1 ? subTemplates[0] : undefined;
  }

  const getPath = () => {
    return `/${tabTemplate.cloudServiceProvider}/${tabTemplate.entityName}/${entityId}/${subType}`;
  }

  useEffect(() => {
    const init = async () => {
      // Load column data.
      const subTemplate = getSubTemplate();
      if (subTemplate) {
        let newDataColumnList: DataColumn[] = subTemplate.columns.map((column) => {
          return { key: column.name, label: column.labelName };
        });
        setDataColumnList(newDataColumnList);
  
        // Load entity data.
        const entityTypeId = `${tabTemplate.cloudServiceProvider}_${tabTemplate.entityName}_${subType}`;
        const filter: {
            [key: string]: string;
        } = {};
        const filterKey = `filter[${tabTemplate.entityName}_entity_id]`;
        filter[filterKey] = entityId;
        filter['filter[cloud_context]'] = cloudContext;
        const rawData = await getEntityListAll(entityTypeId, filter);
        setDataRecordList(convertEntityDataToDataRecord(entityTypeId, rawData, subTemplate.columns as EntityColumn[], cloudContextList, {}));
        setLoadingFlg(false);
      }
    }

    init();
  }, [cloudContext, tabTemplate, entityId, subType]);

  return <>
    <PageTitle />
    <Breadcrumbs />
    <SideBar isOpenCsp/>
    <InfoTabs cloudContext={cloudContext} tabTemplate={tabTemplate} entityId={entityId} subType={subType} />
    <Container fluid className="px-0">
      <Row>
        <Col>
          <Form>
            {
              loadingFlg
                ? <LoadingSpinner />
                : <DataTable
                dataColumnList={dataColumnList}
                dataRecordList={dataRecordList}
                sortInfo={sortInfo}
                setSortInfo={setSortInfo}
                hasOperationLinks={false}
                operationLinksName="Operations links"
                detailInfo={
                  typeof getSubTemplate() !== 'undefined'
                    ? {
                      column: 'name',
                      path: getPath()
                    }
                    : undefined
                } />
            }
          </Form>
        </Col>
      </Row>
    </Container>
  </>;

}

export default EntitySubViewPage;
